@@ -126,17 +126,23 @@ typedef enum {
 typedef enum {
 	BRASERO_AUDIO_FORMAT_NONE		= 0,
 	BRASERO_AUDIO_FORMAT_UNDEFINED		= 1,
-	BRASERO_AUDIO_FORMAT_4_CHANNEL		= 1 << 1,
+	BRASERO_AUDIO_FORMAT_DTS		= 1 << 1,
 	BRASERO_AUDIO_FORMAT_RAW		= 1 << 2,
 	BRASERO_AUDIO_FORMAT_AC3		= 1 << 3,
 	BRASERO_AUDIO_FORMAT_MP2		= 1 << 4,
+
 	BRASERO_AUDIO_FORMAT_44100		= 1 << 5,
 	BRASERO_AUDIO_FORMAT_48000		= 1 << 6,
+
+
 	BRASERO_VIDEO_FORMAT_UNDEFINED		= 1 << 7,
 	BRASERO_VIDEO_FORMAT_VCD		= 1 << 8,
 	BRASERO_VIDEO_FORMAT_VIDEO_DVD		= 1 << 9,
 
-	BRASERO_METADATA_INFO			= 1 << 10
+	BRASERO_METADATA_INFO			= 1 << 10,
+
+	/* Deprecated */
+	BRASERO_AUDIO_FORMAT_4_CHANNEL		= 0
 } BraseroStreamFormat;
 
 #define BRASERO_STREAM_FORMAT_AUDIO(stream_FORMAT)	((stream_FORMAT) & 0x007F)
