@@ -53,6 +53,9 @@
 #include "brasero-drive.h"
 #include "brasero-medium-monitor.h"
 
+#include "brasero-burn-lib.h"
+#include "burn-caps.h"
+
 static BraseroPluginManager *plugin_manager = NULL;
 static BraseroMediumMonitor *medium_manager = NULL;
 static BraseroBurnCaps *default_caps = NULL;
@@ -84,11 +87,12 @@ brasero_burn_action_to_string (BraseroBurnAction action)
 							N_("Transcoding song"),
 							N_("Preparing to write"),
 							N_("Writing leadin"),
-							N_("Writing CD-TEXT information"),
+							N_("Writing CD-Text information"),
 							N_("Finalizing"),
 							N_("Writing leadout"),
 						        N_("Starting to record"),
-							N_("Success") };
+							N_("Success"),
+							N_("Ejecting medium")};
 	return _(strings [action]);
 }
 
