@@ -62,7 +62,7 @@
 
 
 const gchar *types [] = {	N_("File"),
-				N_("CDROM"),
+				N_("CD-ROM"),
 				N_("CD-R"),
 				N_("CD-RW"),
 				N_("DVD-ROM"),
@@ -85,6 +85,10 @@ typedef struct _BraseroMediumPrivate BraseroMediumPrivate;
 struct _BraseroMediumPrivate
 {
 	GThread *probe;
+	GMutex *mutex;
+	GCond *cond;
+	GCond *cond_probe;
+
 	gint probe_id;
 
 	GSList *tracks;
@@ -2323,8 +2327,10 @@ brasero_medium_get_medium_type (BraseroMedium *self,
 
 		/* If this fails it means that this drive is probably older than
 		 * MMC1 spec or does not conform to it. */
-		if (result != TRUE)
+		if (result != TRUE) {
+			priv->info = BRASERO_MEDIUM_NONE;
 			return FALSE;
+		}
 
 		/* The only thing here left to determine is if that's a WRITABLE
 		 * or a REWRITABLE. To determine that information, we need to
@@ -2336,7 +2342,7 @@ brasero_medium_get_medium_type (BraseroMedium *self,
 						 &size,
 						 NULL);
 		if (result != BRASERO_SCSI_OK) {
-			/* CDROM */
+			/* CD-ROM */
 			priv->info = BRASERO_MEDIUM_CDROM;
 			priv->type = types [1];
 		}
@@ -2368,6 +2374,10 @@ brasero_medium_get_medium_type (BraseroMedium *self,
 	}
 
 	switch (profile) {
+	case BRASERO_SCSI_PROF_EMPTY:
+		priv->info = BRASERO_MEDIUM_NONE;
+		return FALSE;
+
 	case BRASERO_SCSI_PROF_CDROM:
 		priv->info = BRASERO_MEDIUM_CDROM;
 		priv->type = types [1];
@@ -2925,12 +2935,11 @@ brasero_medium_probed (gpointer data)
 {
 	BraseroMediumPrivate *priv;
 
+	g_return_val_if_fail (BRASERO_IS_MEDIUM (data), FALSE);
+
 	priv = BRASERO_MEDIUM_PRIVATE (data);
 
-	if (priv->probe) {
-		g_thread_join (priv->probe);
-		priv->probe = NULL;
-	}
+	priv->probe_id = 0;
 
 	/* This signal must be emitted in the main thread */
 	GDK_THREADS_ENTER ();
@@ -2939,7 +2948,6 @@ brasero_medium_probed (gpointer data)
 		       0);
 	GDK_THREADS_LEAVE ();
 
-	priv->probe_id = 0;
 	return FALSE;
 }
 
@@ -2947,6 +2955,7 @@ static gpointer
 brasero_medium_probe_thread (gpointer self)
 {
 	gint counter = 0;
+	GTimeVal wait_time;
 	const gchar *device;
 	BraseroScsiErrCode code;
 	BraseroMediumPrivate *priv;
@@ -2965,52 +2974,76 @@ brasero_medium_probe_thread (gpointer self)
 	while (!handle && counter <= BRASERO_MEDIUM_OPEN_ATTEMPTS) {
 		sleep (1);
 
-		if (priv->probe_cancelled) {
-			priv->probe = NULL;
-			return NULL;
-		}
+		if (priv->probe_cancelled)
+			goto end;
 
 		counter ++;
 		handle = brasero_device_handle_open (device, FALSE, &code);
 	}
 
-	if (priv->probe_cancelled) {
-		priv->probe = NULL;
-		return NULL;
+	if (!handle) {
+		BRASERO_MEDIA_LOG ("Open () failed: medium busy");
+		goto end;
 	}
 
-	if (handle) {
-		BRASERO_MEDIA_LOG ("Open () succeeded");
+	if (priv->probe_cancelled) {
+		brasero_device_handle_close (handle);
+		goto end;
+	}
 
-		/* NOTE: if we wanted to know the status we'd need to read the 
-		 * error code variable which is currently NULL */
-		while (brasero_spc1_test_unit_ready (handle, &code) != BRASERO_SCSI_OK) {
-			if (code != BRASERO_SCSI_NOT_READY) {
-				priv->probe = NULL;
-				brasero_device_handle_close (handle);
-				BRASERO_MEDIA_LOG ("Device does not respond");
-				break;
-			}
+	BRASERO_MEDIA_LOG ("Open () succeeded");
 
-			sleep (2);
+	/* NOTE: if we wanted to know the status we'd need to read the 
+	 * error code variable which is currently NULL */
+	while (brasero_spc1_test_unit_ready (handle, &code) != BRASERO_SCSI_OK) {
+		if (code == BRASERO_SCSI_NO_MEDIUM) {
+			BRASERO_MEDIA_LOG ("No medium inserted");
+			priv->info = BRASERO_MEDIUM_NONE;
 
-			if (priv->probe_cancelled) {
-				priv->probe = NULL;
-				brasero_device_handle_close (handle);
-				BRASERO_MEDIA_LOG ("Device probing cancelled");
-				return NULL;
-			}
+			brasero_device_handle_close (handle);
+			goto end;
+		}
+		else if (code != BRASERO_SCSI_NOT_READY) {
+			BRASERO_MEDIA_LOG ("Device does not respond");
+
+			brasero_device_handle_close (handle);
+			goto end;
 		}
 
-		BRASERO_MEDIA_LOG ("Device ready");
+		g_get_current_time (&wait_time);
+		g_time_val_add (&wait_time, 2000000);
 
-		brasero_medium_init_real (BRASERO_MEDIUM (self), handle);
-		brasero_device_handle_close (handle);
+		g_mutex_lock (priv->mutex);
+		g_cond_timed_wait (priv->cond_probe,
+		                   priv->mutex,
+		                   &wait_time);
+		g_mutex_unlock (priv->mutex);
+
+		if (priv->probe_cancelled) {
+			BRASERO_MEDIA_LOG ("Device probing cancelled");
+
+			brasero_device_handle_close (handle);
+			goto end;
+		}
 	}
-	else
-		BRASERO_MEDIA_LOG ("Open () failed: medium busy");
 
-	priv->probe_id = g_idle_add (brasero_medium_probed, self);
+	BRASERO_MEDIA_LOG ("Device ready");
+
+	brasero_medium_init_real (BRASERO_MEDIUM (self), handle);
+	brasero_device_handle_close (handle);
+
+end:
+
+	if (!priv->probe_cancelled)
+		priv->probe_id = g_idle_add (brasero_medium_probed, self);
+
+	g_mutex_lock (priv->mutex);
+	priv->probe = NULL;
+	g_cond_broadcast (priv->cond);
+	g_mutex_unlock (priv->mutex);
+
+	g_thread_exit (0);
+
 	return NULL;
 }
 
@@ -3026,10 +3059,12 @@ brasero_medium_probe (BraseroMedium *self)
 	 * thread then our whole UI blocks. This medium won't be exported by the
 	 * BraseroDrive that exported until it returns PROBED signal.
 	 * One (good) side effect is that it also improves start time. */
+	g_mutex_lock (priv->mutex);
 	priv->probe = g_thread_create (brasero_medium_probe_thread,
 				       self,
-				       TRUE,
+				       FALSE,
 				       NULL);
+	g_mutex_unlock (priv->mutex);
 }
 
 static void
@@ -3051,6 +3086,10 @@ brasero_medium_init (BraseroMedium *object)
 	priv = BRASERO_MEDIUM_PRIVATE (object);
 	priv->next_wr_add = -1;
 
+	priv->mutex = g_mutex_new ();
+	priv->cond = g_cond_new ();
+	priv->cond_probe = g_cond_new ();
+
 	/* we can't do anything here since properties haven't been set yet */
 }
 
@@ -3063,21 +3102,41 @@ brasero_medium_finalize (GObject *object)
 
 	BRASERO_MEDIA_LOG ("Finalizing Medium object");
 
+	g_mutex_lock (priv->mutex);
 	if (priv->probe) {
-		GThread *probe;
-
-		probe = priv->probe;
+		/* This to signal that we are cancelling */
 		priv->probe_cancelled = TRUE;
 
-		g_thread_join (probe);
-		priv->probe = NULL;
+		/* This is to wake up the thread if it
+		 * was asleep waiting to retry to get
+		 * hold of a handle to probe the drive */
+		g_cond_signal (priv->cond_probe);
+
+		/* Wait for the end of the thread */
+		g_cond_wait (priv->cond, priv->mutex);
 	}
+	g_mutex_unlock (priv->mutex);
 
 	if (priv->probe_id) {
 		g_source_remove (priv->probe_id);
 		priv->probe_id = 0;
 	}
 
+	if (priv->mutex) {
+		g_mutex_free (priv->mutex);
+		priv->mutex = NULL;
+	}
+
+	if (priv->cond) {
+		g_cond_free (priv->cond);
+		priv->cond = NULL;
+	}
+
+	if (priv->cond_probe) {
+		g_cond_free (priv->cond_probe);
+		priv->cond_probe = NULL;
+	}
+
 	if (priv->id) {
 		g_free (priv->id);
 		priv->id = NULL;
@@ -3192,14 +3251,6 @@ brasero_medium_class_init (BraseroMediumClass *klass)
 	                                                      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 }
 
-
-/* This function is not public API yet because it was too
- * late; so use it internally for now. It's mainly for 
- * convenience.*/
-gboolean
-brasero_drive_can_write_media (BraseroDrive *drive,
-                               BraseroMedia media);
-
 /**
  * brasero_medium_can_be_written:
  * @medium: #BraseroMedium
@@ -3256,7 +3307,7 @@ brasero_medium_can_be_rewritten (BraseroMedium *medium)
 	||  BRASERO_MEDIUM_IS (priv->info, BRASERO_MEDIUM_DVDRW_PLUS_DL)
 	||  BRASERO_MEDIUM_IS (priv->info, BRASERO_MEDIUM_DVD_RAM)
 	||  BRASERO_MEDIUM_IS (priv->info, BRASERO_MEDIUM_BDRE))
-		return priv->write_command != 0;
+		return TRUE;
 
 	return FALSE;
 }
@@ -3266,6 +3317,8 @@ brasero_medium_can_be_rewritten (BraseroMedium *medium)
  *
  * Gets whether the medium supports SAO.
  *
+ * Since 2.29
+ *
  * Return value: a #gboolean. TRUE if the medium can use SAO write mode , FALSE otherwise.
  *
  **/
@@ -3286,6 +3339,8 @@ brasero_medium_can_use_sao (BraseroMedium *medium)
  *
  * Gets whether the medium supports TAO.
  *
+ * Since 2.29
+ *
  * Return value: a #gboolean. TRUE if the medium can use TAO write mode, FALSE otherwise.
  *
  **/
