@@ -1,9 +1,9 @@
-/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 8; tab-width: 8 -*-
- *
+/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
+/*
  * Copyright (C) 2003 Novell, Inc.
  * Copyright (C) 2003-2004 Red Hat, Inc.
  * Copyright (C) 2005 William Jon McCann <mccann@jhu.edu>
- * Copyright (C) 2008 Philippe Rouquier <bonfire-app@wanadoo.fr> (modified to work with brasero)
+ * Copyright (C) 2008-2009 Philippe Rouquier <bonfire-app@wanadoo.fr> (modified to work with brasero)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -29,6 +29,9 @@
 #include <glib/gi18n-lib.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
+
+#include <gconf/gconf-client.h>
+
 #include <libnautilus-extension/nautilus-menu-provider.h>
 #include <libnautilus-extension/nautilus-location-widget-provider.h>
 
@@ -36,8 +39,31 @@
 #include "brasero-medium-monitor.h"
 #include "brasero-drive.h"
 #include "brasero-medium.h"
+
+#include "brasero-burn-lib.h"
+#include "brasero-track.h"
+#include "brasero-track-data-cfg.h"
+#include "brasero-track-image-cfg.h"
+#include "brasero-track-disc.h"
+#include "brasero-session.h"
+#include "brasero-session-cfg.h"
+
+#include "brasero-tool-dialog.h"
+#include "brasero-blank-dialog.h"
+#include "brasero-sum-dialog.h"
+
+#include "brasero-burn-options.h"
+#include "brasero-burn-dialog.h"
+
 #include "nautilus-burn-bar.h"
 
+#include "brasero-project-name.h"
+
+#include "brasero-misc.h"
+
+#include "brasero-media-private.h"
+#include "burn-debug.h"
+
 #define BURN_URI "burn:///"
 
 #define NAUTILUS_TYPE_DISC_BURN  (nautilus_disc_burn_get_type ())
@@ -78,171 +104,290 @@ static GObjectClass *parent_class;
 //#define DEBUG_PRINT(format_MACRO,...)           g_print (format_MACRO, ##__VA_ARGS__);
 #define DEBUG_PRINT(format_MACRO,...)             
 
+
 static void
-launch_process (GPtrArray *argv, GtkWindow *parent)
+launch_brasero_on_window_session (BraseroSessionCfg	*session,
+                                  const gchar		*dialog_title,
+				  GtkWidget		*options,
+				  GtkWindow		*window)
 {
-        GtkWidget *dialog;
-        GError *error;
-        gchar **args;
+	const gchar			*icon_name;
+	GtkWidget		*dialog;
+	GtkResponseType		 result;
 
-        if (parent && GTK_WIDGET (parent)->window) {
-                guint xid;
+	/* Get the icon for the window */
+	if (window)
+		icon_name = gtk_window_get_icon_name (window);
+	else
+		icon_name = "brasero";
 
-		xid = gdk_x11_drawable_get_xid (GDK_DRAWABLE (GTK_WIDGET (parent)->window));
-                if (xid > 0) {
-                        g_ptr_array_add (argv, g_strdup ("-x"));
-                        g_ptr_array_add (argv, g_strdup_printf ("%d", xid));
-                }
-        }
+	/* run option dialog */
+	dialog = brasero_burn_options_new (session);
 
-        error = NULL;
-        g_ptr_array_add (argv, NULL);
-        args = (gchar **) g_ptr_array_free (argv, FALSE);
-        if (!g_spawn_async (NULL,
-                            args, NULL,
-                            0,
-                            NULL, NULL,
-                            NULL,
-                            &error)) {
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), icon_name);
 
-                dialog = gtk_message_dialog_new (parent,
-                                                 GTK_DIALOG_MODAL,
-                                                 GTK_MESSAGE_WARNING,
-                                                 GTK_BUTTONS_OK,
-                                                 _("Unable to launch the cd burner application"));
+	if (dialog_title)
+		gtk_window_set_title (GTK_WINDOW (dialog), dialog_title);
 
-                gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-                                                          "%s",
-                                                          error->message);
+	if (options)
+		brasero_burn_options_add_options (BRASERO_BURN_OPTIONS (dialog), options);
 
-                gtk_dialog_run (GTK_DIALOG (dialog));
-                gtk_widget_destroy (dialog);
+	gtk_widget_show (GTK_WIDGET (dialog));
+	result = gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
 
+	if (result != GTK_RESPONSE_OK)
+		return;
 
-                g_error_free (error);
-        }
+	/* now run burn dialog */
+	dialog = brasero_burn_dialog_new ();
 
-        g_strfreev (args);
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), icon_name);
+
+	if (dialog_title)
+		gtk_window_set_title (GTK_WINDOW (dialog), dialog_title);
+
+	brasero_session_cfg_disable (session);
+
+	gtk_widget_show (dialog);
+	gtk_window_present (GTK_WINDOW (dialog));
+	brasero_burn_dialog_run (BRASERO_BURN_DIALOG (dialog),
+				 BRASERO_BURN_SESSION (session));
+
+	gtk_widget_destroy (dialog);
+}
+
+static gboolean
+nautilus_disc_burn_is_empty (GtkWindow *toplevel)
+{
+	GFileEnumerator *enumerator;
+	GFileInfo *info = NULL;
+	GError *error = NULL;
+	GFile *file;
+
+	file = g_file_new_for_uri (BURN_URI);
+	enumerator = g_file_enumerate_children (file,
+						G_FILE_ATTRIBUTE_STANDARD_NAME,
+						G_FILE_QUERY_INFO_NONE,
+						NULL,
+						&error);
+	if (!enumerator) {
+		gchar *string;
+
+		DEBUG_PRINT ("Could not open burn uri %s: %s\n",
+                             uri,
+                             error->message);
+
+		if (!toplevel) {
+			g_error_free (error);
+			return TRUE;
+		}
+
+		string = g_strdup_printf ("%s.", _("An internal error occurred"));
+		brasero_utils_message_dialog (GTK_WIDGET (toplevel),
+					      string,
+					      error ? error->message:NULL,
+					      GTK_MESSAGE_ERROR);
+		g_free (string);
+
+		g_object_unref (file);
+		g_error_free (error);
+		return TRUE;
+	}
+
+	info = g_file_enumerator_next_file (enumerator, NULL, NULL);
+	g_object_unref (enumerator);
+	g_object_unref (file);
+
+	if (!info) {
+		if (!toplevel)
+			return TRUE;
+
+		brasero_utils_message_dialog (GTK_WIDGET (toplevel),
+					      _("Please add files."),
+					      _("There are no files to write to disc"),
+					      GTK_MESSAGE_ERROR);
+		return TRUE;
+	}
+
+	g_object_unref (info);
+	return FALSE;
 }
 
 static void
-launch_brasero_on_window (GtkWindow *window)
+write_activate (GtkWindow *toplevel)
 {
-        int i;
-        GPtrArray        *argv = NULL;
+	BraseroTrackDataCfg	*track;
+	BraseroSessionCfg	*session;
+	GtkWidget 		*name_options;
+	GtkWidget		*options;
+	gchar			*string;
 
-        argv = g_ptr_array_new ();
-        g_ptr_array_add (argv, g_build_filename (BINDIR, "brasero", NULL));
-        g_ptr_array_add (argv, g_strdup ("-n"));
+	if (nautilus_disc_burn_is_empty (toplevel))
+		return;
 
-        launch_process (argv, window);
+	track = brasero_track_data_cfg_new ();
+	brasero_track_data_cfg_add (track, BURN_URI, NULL);
+
+	session = brasero_session_cfg_new ();
+	brasero_burn_session_add_track (BRASERO_BURN_SESSION (session),
+					BRASERO_TRACK (track),
+					NULL);
+	g_object_unref (track);
+
+	/* add name widget here to set the label of the volume */
+	name_options = brasero_project_name_new (NULL);
+	brasero_project_name_set_session (BRASERO_PROJECT_NAME (name_options),
+					  BRASERO_BURN_SESSION (session));
+
+	string = g_strdup_printf ("<b>%s</b>", _("Disc name"));
+	options = brasero_utils_pack_properties (string,
+						 name_options,
+						 NULL);
+	g_free (string);
+	gtk_widget_show_all (options);
+
+	/* NOTE: set the disc we're handling */
+	launch_brasero_on_window_session (session,
+	                                  _("CD/DVD Creator"),
+	                                  options,
+	                                  toplevel);
+
+	/* cleanup */
+	g_object_unref (session);
 }
 
 static void
 write_activate_cb (NautilusMenuItem *item,
                    gpointer          user_data)
 {
-        launch_brasero_on_window (GTK_WINDOW (user_data));
+	write_activate (GTK_WINDOW (user_data));
+}
+
+static void
+launch_brasero_on_window_track (BraseroTrack	*track,
+                                const gchar	*dialog_title,
+				GtkWidget	*options,
+				GtkWindow	*window)
+{
+	BraseroSessionCfg *session;
+
+	/* create a session and add track */
+	session = brasero_session_cfg_new ();
+	brasero_burn_session_add_track (BRASERO_BURN_SESSION (session),
+					BRASERO_TRACK (track),
+					NULL);
+
+	launch_brasero_on_window_session (session,
+	                                  dialog_title,
+	                                  options,
+	                                  window);
+	g_object_unref (session);
 }
 
 static void
 write_iso_activate_cb (NautilusMenuItem *item,
                        gpointer          user_data)
 {
-        NautilusFileInfo *file_info;
-        GPtrArray        *argv = NULL;
-        char             *uri;
-        char             *image_path;
-        int               i;
+	BraseroTrackImageCfg	*track;
+        NautilusFileInfo	*file_info;
+        char			*uri;
 
         file_info = g_object_get_data (G_OBJECT (item), "file_info");
-
         uri = nautilus_file_info_get_uri (file_info);
-        image_path = g_filename_from_uri (uri, NULL, NULL);
 
-        if (image_path == NULL) {
-                g_warning ("Can not get local path for URI %s", uri);
-                g_free (uri);
-                return;
-        }
+	track = brasero_track_image_cfg_new ();
+	brasero_track_image_cfg_set_source (track, uri);
 
-        g_free (uri);
-
-        argv = g_ptr_array_new ();
-        g_ptr_array_add (argv, g_build_filename (BINDIR, "brasero", NULL));
-        g_ptr_array_add (argv, g_strdup ("-i"));
-        g_ptr_array_add (argv, image_path);
-
-        launch_process (argv, GTK_WINDOW (user_data));
+	launch_brasero_on_window_track (BRASERO_TRACK (track),
+	                                _("Write to Disc"),
+	                                NULL,
+	                                GTK_WINDOW (user_data));
+	g_object_unref (track);
 }
 
 static void
 copy_disc_activate_cb (NautilusMenuItem *item,
                        gpointer          user_data)
 {
-        int               i;
-        GPtrArray        *argv = NULL;
-        char             *device_path;
+        char            	*device_path;
+	BraseroMediumMonitor	*monitor;
+	BraseroTrackDisc	*track;
+	BraseroDrive		*drive;
 
         device_path = g_object_get_data (G_OBJECT (item), "drive_device_path");
+	monitor = brasero_medium_monitor_get_default ();
+	drive = brasero_medium_monitor_get_drive (monitor, device_path);
+	g_object_unref (monitor);
 
-        if (!device_path) {
-                g_warning ("Drive device path not specified");
-                return;
-        }
+	track = brasero_track_disc_new ();
+	brasero_track_disc_set_drive (track, drive);
+	g_object_unref (drive);
 
-        argv = g_ptr_array_new ();
-        g_ptr_array_add (argv, g_build_filename (BINDIR, "brasero", NULL));
-        g_ptr_array_add (argv, g_strdup ("-c"));
-        g_ptr_array_add (argv, g_strdup (device_path));
+	launch_brasero_on_window_track (BRASERO_TRACK (track),
+	                                _("Copy Disc"),
+	                                NULL,
+	                                GTK_WINDOW (user_data));
+	g_object_unref (track);
+}
 
-        launch_process (argv, GTK_WINDOW (user_data));
+static void
+tool_dialog_run (BraseroToolDialog	*dialog,
+		 GtkWindow		*toplevel,
+		 NautilusMenuItem	*item)
+{
+	char			*device_path;
+	BraseroDrive		*drive;
+	BraseroMediumMonitor	*monitor;
+
+	device_path = g_object_get_data (G_OBJECT (item), "drive_device_path");
+	if (!device_path) {
+		g_warning ("Drive device path not specified");
+		return;
+	}
+
+	monitor = brasero_medium_monitor_get_default ();
+	drive = brasero_medium_monitor_get_drive (monitor, device_path);
+	g_object_unref (monitor);
+
+	if (drive) {
+		brasero_tool_dialog_set_medium (BRASERO_TOOL_DIALOG (dialog),
+						brasero_drive_get_medium (drive));
+		g_object_unref (drive);
+	}
+
+	/* Get the icon for the window */
+	if (toplevel)
+		gtk_window_set_icon_name (GTK_WINDOW (dialog), gtk_window_get_icon_name (toplevel));
+	else
+		gtk_window_set_icon_name (GTK_WINDOW (dialog), "brasero");
+
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
 static void
 blank_disc_activate_cb (NautilusMenuItem *item,
                         gpointer          user_data)
 {
-        int               i;
-        GPtrArray        *argv = NULL;
-        char             *device_path;
+	BraseroBlankDialog *dialog;
 
-        device_path = g_object_get_data (G_OBJECT (item), "drive_device_path");
-
-        if (!device_path) {
-                g_warning ("Drive device path not specified");
-                return;
-        }
-
-        argv = g_ptr_array_new ();
-        g_ptr_array_add (argv, g_build_filename (BINDIR, "brasero", NULL));
-        g_ptr_array_add (argv, g_strdup ("-b"));
-        g_ptr_array_add (argv, g_strdup (device_path));
-
-        launch_process (argv, GTK_WINDOW (user_data));
+	dialog = brasero_blank_dialog_new ();
+	tool_dialog_run (BRASERO_TOOL_DIALOG (dialog),
+			 GTK_WINDOW (user_data),
+			 item);
 }
 
 static void
 check_disc_activate_cb (NautilusMenuItem *item,
                         gpointer          user_data)
 {
-        int               i;
-        GPtrArray        *argv = NULL;
-        char             *device_path;
+	BraseroSumDialog *dialog;
 
-        device_path = g_object_get_data (G_OBJECT (item), "drive_device_path");
-
-        if (!device_path) {
-                g_warning ("Drive device path not specified");
-                return;
-        }
-
-        argv = g_ptr_array_new ();
-        g_ptr_array_add (argv, g_build_filename (BINDIR, "brasero", NULL));
-        g_ptr_array_add (argv, g_strdup ("-k"));
-        g_ptr_array_add (argv, g_strdup (device_path));
-
-        launch_process (argv, GTK_WINDOW (user_data));
+	dialog = brasero_sum_dialog_new ();
+	tool_dialog_run (BRASERO_TOOL_DIALOG (dialog),
+			 GTK_WINDOW (user_data),
+			 item);
 }
 
 static gboolean
@@ -372,8 +517,8 @@ nautilus_disc_burn_get_file_items (NautilusMenuProvider *provider,
         if (is_iso) {
                 /* Whether or not this file is local is not a problem */
                 item = nautilus_menu_item_new ("NautilusDiscBurn::write_iso",
-                                               _("_Write to Disc..."),
-                                               _("Write disc image to a CD or DVD disc"),
+                                               _("_Write to Disc…"),
+                                               _("Write disc image to a CD or DVD"),
                                                "media-optical-data-new");
                 g_object_set_data (G_OBJECT (item), "file_info", file_info);
                 g_object_set_data (G_OBJECT (item), "window", window);
@@ -419,45 +564,70 @@ nautilus_disc_burn_get_file_items (NautilusMenuProvider *provider,
             && volume != NULL
             && drive_is_cd_device (drive)
             && ! volume_is_blank (volume)) {
-                char *device_path;
+                char			*device_path;
+		BraseroMediumMonitor	*monitor;
+		BraseroDrive		*bdrive;
+		BraseroMedium		*medium;
+		BraseroMedia		 media;
+		BraseroTrackType	*type;
 
                 device_path = g_volume_get_identifier (volume, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
+		monitor = brasero_medium_monitor_get_default ();
+		bdrive = brasero_medium_monitor_get_drive (monitor, device_path);
+		g_object_unref (monitor);
 
-                /* user may want to copy it ... */
-                item = nautilus_menu_item_new ("NautilusDiscBurn::copy_disc",
-                                               _("_Copy Disc..."),
-                                               _("Create a copy of this CD or DVD disc"),
-                                               "media-optical-copy");
-                g_object_set_data (G_OBJECT (item), "file_info", file_info);
-                g_object_set_data (G_OBJECT (item), "window", window);
-                g_object_set_data_full (G_OBJECT (item), "drive_device_path", g_strdup (device_path), g_free);
-                g_signal_connect (item, "activate",
-                                  G_CALLBACK (copy_disc_activate_cb), window);
-                items = g_list_append (items, item);
+		medium = brasero_drive_get_medium (bdrive);
+		media = brasero_medium_get_status (medium);
+		g_object_unref (bdrive);
 
-                /* ... or if it's a rewritable medium to blank it ... */
-                item = nautilus_menu_item_new ("NautilusDiscBurn::blank_disc",
-                                               _("_Blank Disc..."),
-                                               _("Blank this CD or DVD disc"),
-                                               "media-optical-blank");
-                g_object_set_data (G_OBJECT (item), "file_info", file_info);
-                g_object_set_data (G_OBJECT (item), "window", window);
-                g_object_set_data_full (G_OBJECT (item), "drive_device_path", g_strdup (device_path), g_free);
-                g_signal_connect (item, "activate",
-                                  G_CALLBACK (blank_disc_activate_cb), window);
-                items = g_list_append (items, item);
+		type = brasero_track_type_new ();
+		brasero_track_type_set_has_medium (type);
+		brasero_track_type_set_medium_type (type, media);
+		if (brasero_burn_library_input_supported (type) == BRASERO_BURN_OK) {
+			/* user may want to copy it ... */
+			item = nautilus_menu_item_new ("NautilusDiscBurn::copy_disc",
+						       _("_Copy Disc…"),
+						       _("Create a copy of this CD or DVD"),
+						       "media-optical-copy");
+			g_object_set_data (G_OBJECT (item), "file_info", file_info);
+			g_object_set_data (G_OBJECT (item), "window", window);
+			g_object_set_data_full (G_OBJECT (item), "drive_device_path", g_strdup (device_path), g_free);
+			g_signal_connect (item, "activate", G_CALLBACK (copy_disc_activate_cb), window);
+			items = g_list_append (items, item);
+		}
+		brasero_track_type_free (type);
 
-                /* ... or verify medium. */
-                item = nautilus_menu_item_new ("NautilusDiscBurn::check_disc",
-                                               _("_Check Disc..."),
-                                               _("Check the data integrity on this CD or DVD disc"),
-                                               NULL);
-                g_object_set_data (G_OBJECT (item), "file_info", file_info);
-                g_object_set_data (G_OBJECT (item), "window", window);
-                g_object_set_data_full (G_OBJECT (item), "drive_device_path", g_strdup (device_path), g_free);
-                g_signal_connect (item, "activate",
-                                  G_CALLBACK (check_disc_activate_cb), window);
-                items = g_list_append (items, item);
+		if (brasero_burn_library_get_media_capabilities (media) & BRASERO_MEDIUM_REWRITABLE) {
+			/* ... or if it's a rewritable medium to blank it ... */
+			item = nautilus_menu_item_new ("NautilusDiscBurn::blank_disc",
+						       _("_Blank Disc…"),
+						       _("Blank this CD or DVD"),
+						       "media-optical-blank");
+			g_object_set_data (G_OBJECT (item), "file_info", file_info);
+			g_object_set_data (G_OBJECT (item), "window", window);
+			g_object_set_data_full (G_OBJECT (item), "drive_device_path", g_strdup (device_path), g_free);
+			g_signal_connect (item, "activate",
+					  G_CALLBACK (blank_disc_activate_cb), window);
+			items = g_list_append (items, item);
+		}
+
+		/* - library should be able to checksum
+		 * - disc must have a data session */
+		if (brasero_burn_library_can_checksum ()
+		&& (media & BRASERO_MEDIUM_HAS_DATA)) {
+			/* ... or verify medium. */
+			item = nautilus_menu_item_new ("NautilusDiscBurn::check_disc",
+						       _("_Check Disc…"),
+						       _("Check the data integrity on this CD or DVD"),
+						       NULL);
+			g_object_set_data (G_OBJECT (item), "file_info", file_info);
+			g_object_set_data (G_OBJECT (item), "window", window);
+			g_object_set_data_full (G_OBJECT (item), "drive_device_path", g_strdup (device_path), g_free);
+			g_signal_connect (item, "activate",
+					  G_CALLBACK (check_disc_activate_cb),
+			                  window);
+			items = g_list_append (items, item);
+		}
 
                 g_free (device_path);
         }
@@ -493,8 +663,8 @@ nautilus_disc_burn_get_background_items (NautilusMenuProvider *provider,
                 NautilusMenuItem *item;
 
                 item = nautilus_menu_item_new ("NautilusDiscBurn::write_menu",
-                                               _("_Write to Disc..."),
-                                               _("Write contents to a CD or DVD disc"),
+                                               _("_Write to Disc…"),
+                                               _("Write contents to a CD or DVD"),
                                                "brasero");
                 g_signal_connect (item, "activate",
                                   G_CALLBACK (write_activate_cb),
@@ -530,58 +700,10 @@ nautilus_disc_burn_menu_provider_iface_init (NautilusMenuProviderIface *iface)
 }
 
 static void
-bar_activated_cb (NautilusDiscBurnBar *bar,
-                  gpointer         data)
+bar_activated_cb (NautilusDiscBurnBar	*bar,
+                  gpointer		 user_data)
 {
-        launch_brasero_on_window (GTK_WINDOW (data));
-}
-
-static gboolean
-dir_is_empty (const char *uri)
-{
-        GFile           *file;
-        GFileEnumerator *enumerator;
-        GError          *error;
-        gboolean         found_file;
-
-        file = g_file_new_for_uri (uri);
-
-        error = NULL;
-        enumerator = g_file_enumerate_children (file,
-                                                G_FILE_ATTRIBUTE_STANDARD_NAME ","
-                                                G_FILE_ATTRIBUTE_STANDARD_TYPE ","
-                                                G_FILE_ATTRIBUTE_ACCESS_CAN_READ,
-                                                0,
-                                                NULL,
-                                                &error);
-        if (enumerator == NULL) {
-                DEBUG_PRINT ("Could not open burn uri %s: %s\n",
-                             uri,
-                             error->message);
-                g_error_free (error);
-                return TRUE;
-        }
-
-        found_file = FALSE;
-
-        while (TRUE) {
-                GFileInfo *info;
-
-                info = g_file_enumerator_next_file (enumerator, NULL, NULL);
-                if (info == NULL) {
-                        break;
-                }
-
-                g_object_unref (info);
-
-                found_file = TRUE;
-                break;
-        }
-
-        g_object_unref (enumerator);
-        g_object_unref (file);
-
-        return !found_file;
+	write_activate (GTK_WINDOW (user_data));
 }
 
 static void
@@ -653,7 +775,7 @@ update_empty_idle (NautilusDiscBurn *burn)
 
         burn->priv->empty_update_id = 0;
 
-        is_empty = dir_is_empty (BURN_URI);
+        is_empty = nautilus_disc_burn_is_empty (NULL);
 
         DEBUG_PRINT ("Dir is %s\n", is_empty ? "empty" : "not empty");
 
@@ -714,7 +836,7 @@ start_monitor (NautilusDiscBurn *burn)
                                                              NULL,
                                                              &error);
         if (burn->priv->burn_monitor == NULL) {
-                g_warning ("Unable to add monitor: %s", error->message);
+                DEBUG_PRINT ("Unable to add monitor: %s", error->message);
                 g_error_free (error);
                 goto out;
         }
@@ -725,7 +847,7 @@ start_monitor (NautilusDiscBurn *burn)
                           G_CALLBACK (burn_monitor_cb),
                           burn);
 
-        burn->priv->empty = dir_is_empty (BURN_URI);
+        burn->priv->empty = nautilus_disc_burn_is_empty (NULL);
 
         DEBUG_PRINT ("Init burn extension, empty: %d\n", burn->priv->empty);
 
@@ -843,9 +965,20 @@ nautilus_disc_burn_register_type (GTypeModule *module)
 void
 nautilus_module_initialize (GTypeModule *module)
 {
-        DEBUG_PRINT ("Initializing nautilus disc recorder\n");
+	GConfClient *client;
+
+        DEBUG_PRINT ("Initializing nautilus-disc-recorder\n");
+
+	client = gconf_client_get_default ();
+	if (gconf_client_get_bool (client, "/apps/brasero/nautilus-extension-debug", NULL)) {
+		brasero_media_library_set_debug (TRUE);
+		brasero_burn_library_set_debug (TRUE);
+	}
+	g_object_unref (client);
+
+	brasero_media_library_start ();
+        brasero_burn_library_start (NULL, NULL);
 
-        brasero_media_library_start ();
         DEBUG_PRINT ("Libbrasero-media started\n");
 
         nautilus_disc_burn_register_type (module);
@@ -858,6 +991,7 @@ nautilus_module_shutdown (void)
 
         /* Don't do that in case another module would need the library */
         //brasero_media_library_stop ();
+        //brasero_burn_library_stop ();
 }
 
 void
