@@ -55,12 +55,19 @@
 #include "burn-process.h"
 #include "brasero-plugin-registration.h"
 #include "burn-cdrtools.h"
-#include "burn-cdrecord.h"
 
 #include "brasero-tags.h"
 #include "brasero-track-image.h"
 #include "brasero-track-stream.h"
 
+
+#define BRASERO_TYPE_CD_RECORD         (brasero_cdrecord_get_type ())
+#define BRASERO_CD_RECORD(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), BRASERO_TYPE_CD_RECORD, BraseroCDRecord))
+#define BRASERO_CD_RECORD_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), BRASERO_TYPE_CD_RECORD, BraseroCDRecordClass))
+#define BRASERO_IS_CD_RECORD(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), BRASERO_TYPE_CD_RECORD))
+#define BRASERO_IS_CD_RECORD_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), BRASERO_TYPE_CD_RECORD))
+#define BRASERO_CD_RECORD_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), BRASERO_TYPE_CD_RECORD, BraseroCDRecordClass))
+
 BRASERO_PLUGIN_BOILERPLATE (BraseroCDRecord, brasero_cdrecord, BRASERO_TYPE_PROCESS, BraseroProcess);
 
 struct _BraseroCDRecordPrivate {
@@ -107,13 +114,13 @@ brasero_cdrecord_stderr_read (BraseroProcess *process, const gchar *line)
 						BRASERO_BURN_ERROR_MEDIUM_SPACE,
 						_("Not enough space available on the disc")));
 	}
-	else if (strstr (line ,"cdrecord: A write error occured")
+	else if (strstr (line ,"cdrecord: A write error occurred")
 	     ||  strstr (line, "Could not write Lead-in")
 	     ||  strstr (line, "Cannot fixate disk")) {
 		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new (BRASERO_BURN_ERROR,
 						BRASERO_BURN_ERROR_WRITE_MEDIUM,
-						_("An error occured while writing to disc")));
+						_("An error occurred while writing to disc")));
 	}
 	else if (strstr (line, "DMA speed too slow") != NULL) {
 		brasero_job_error (BRASERO_JOB (process),
@@ -196,13 +203,13 @@ brasero_cdrecord_stderr_read (BraseroProcess *process, const gchar *line)
 	**/
 
 	/** For these we'd rather have a message saying "cdrecord failed"
-	 *  as an internal error occured says nothing/even less
+	 *  as an internal error occurred says nothing/even less
 	else if (strstr (line, "Bad file descriptor. read error on input file")
 	     ||  strstr (line, "Input buffer error, aborting")) {
 		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new (BRASERO_BURN_ERROR,
 						BRASERO_BURN_ERROR_GENERAL,
-						_("An internal error occured")));
+						_("An internal error occurred")));
 	}
 
 	**/
@@ -424,7 +431,7 @@ brasero_cdrecord_write_inf (BraseroCDRecord *cdrecord,
 
 		if (dot && dot > separator)
 			path = g_strdup_printf ("%.*s.inf",
-						dot - path,
+						(int) (dot - path),
 						path);
 		else
 			path = g_strdup_printf ("%s.inf",
@@ -680,7 +687,7 @@ error:
 	g_set_error (error,
 		     BRASERO_BURN_ERROR,
 		     BRASERO_BURN_ERROR_GENERAL,
-		     _("An internal error occured (%s)"), 
+		     _("An internal error occurred (%s)"), 
 		     g_strerror (errsv));
 
 	return BRASERO_BURN_ERR;
@@ -710,19 +717,31 @@ brasero_cdrecord_write_infs (BraseroCDRecord *cdrecord,
 	for (iter = tracks; iter; iter = iter->next) {
 		goffset sectors;
 		BraseroTrack *track;
+		const gchar *track_inf;
 
 		track = iter->data;
-		result = brasero_cdrecord_write_inf (cdrecord,
-						     argv,
-						     track,
-						     tmpdir,
-						     album,
-						     index,
-						     start,
-						     (iter->next == NULL),
-						     error);
-		if (result != BRASERO_BURN_OK)
-			return result;
+
+		track_inf = brasero_track_tag_lookup_string (track, BRASERO_CDRTOOLS_TRACK_INF_FILE);
+		if (track_inf) {
+			BRASERO_JOB_LOG (cdrecord, "Already existing .inf file");
+
+			/* There is already an .inf file associated with this track */
+			if (argv)
+				g_ptr_array_add (argv, g_strdup (track_inf));
+		}
+		else {
+			result = brasero_cdrecord_write_inf (cdrecord,
+							     argv,
+							     track,
+							     tmpdir,
+							     album,
+							     index,
+							     start,
+							     (iter->next == NULL),
+							     error);
+			if (result != BRASERO_BURN_OK)
+				return result;
+		}
 
 		index ++;
 		sectors = 0;
@@ -797,7 +816,7 @@ brasero_cdrecord_set_argv_record (BraseroCDRecord *cdrecord,
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
-				     _("An internal error occured"));
+				     _("An internal error occurred"));
 			return BRASERO_BURN_ERR;
 		}
 		
@@ -812,7 +831,7 @@ brasero_cdrecord_set_argv_record (BraseroCDRecord *cdrecord,
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
-				     _("An internal error occured"));
+				     _("An internal error occurred"));
 			return BRASERO_BURN_ERR;
 		}
 
@@ -1187,7 +1206,6 @@ brasero_cdrecord_export_caps (BraseroPlugin *plugin, gchar **error)
 	input = brasero_caps_audio_new (BRASERO_PLUGIN_IO_ACCEPT_PIPE|
 					BRASERO_PLUGIN_IO_ACCEPT_FILE,
 					BRASERO_AUDIO_FORMAT_RAW|
-					BRASERO_AUDIO_FORMAT_44100|
 					BRASERO_METADATA_INFO);
 
 	brasero_plugin_link_caps (plugin, output, input);
@@ -1195,8 +1213,7 @@ brasero_cdrecord_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	input = brasero_caps_audio_new (BRASERO_PLUGIN_IO_ACCEPT_PIPE|
 					BRASERO_PLUGIN_IO_ACCEPT_FILE,
-					BRASERO_AUDIO_FORMAT_RAW|
-					BRASERO_AUDIO_FORMAT_44100);
+					BRASERO_AUDIO_FORMAT_RAW);
 
 	brasero_plugin_link_caps (plugin, output, input);
 	g_slist_free (output);
@@ -1255,7 +1272,7 @@ brasero_cdrecord_export_caps (BraseroPlugin *plugin, gchar **error)
 				  BRASERO_BURN_FLAG_NOGRACE,
 				  BRASERO_BURN_FLAG_NONE);
 
-	/* This is a CDR with data data can be merged or at least appended */
+	/* This is a CDR with data; data can be merged or at least appended */
 	brasero_plugin_set_flags (plugin,
 				  BRASERO_MEDIUM_CD|
 				  BRASERO_MEDIUM_WRITABLE|
@@ -1379,10 +1396,10 @@ brasero_cdrecord_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	/* add some configure options */
 	immed = brasero_plugin_conf_option_new (GCONF_KEY_IMMEDIATE_FLAG,
-						_("Enable \"-immed\" flag (see cdrecord manual)"),
+						_("Enable the \"-immed\" flag (see cdrecord manual)"),
 						BRASERO_PLUGIN_OPTION_BOOL);
 	minbuf = brasero_plugin_conf_option_new (GCONF_KEY_MINBUF_VALUE,
-						 _("Minimum drive buffer fill ratio (in %%)(see cdrecord manual):"),
+						 _("Minimum drive buffer fill ratio (in %%) (see cdrecord manual):"),
 						 BRASERO_PLUGIN_OPTION_INT);
 	brasero_plugin_conf_option_int_set_range (minbuf, 25, 95);
 
