@@ -48,7 +48,6 @@
 #include <libburn/libburn.h>
 
 #include "burn-libburnia.h"
-#include "burn-libisofs.h"
 #include "burn-job.h"
 #include "brasero-units.h"
 #include "brasero-plugin-registration.h"
@@ -56,6 +55,14 @@
 #include "brasero-track-data.h"
 #include "brasero-track-image.h"
 
+
+#define BRASERO_TYPE_LIBISOFS         (brasero_libisofs_get_type ())
+#define BRASERO_LIBISOFS(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), BRASERO_TYPE_LIBISOFS, BraseroLibisofs))
+#define BRASERO_LIBISOFS_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), BRASERO_TYPE_LIBISOFS, BraseroLibisofsClass))
+#define BRASERO_IS_LIBISOFS(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), BRASERO_TYPE_LIBISOFS))
+#define BRASERO_IS_LIBISOFS_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), BRASERO_TYPE_LIBISOFS))
+#define BRASERO_LIBISOFS_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), BRASERO_TYPE_LIBISOFS, BraseroLibisofsClass))
+
 BRASERO_PLUGIN_BOILERPLATE (BraseroLibisofs, brasero_libisofs, BRASERO_TYPE_JOB, BraseroJob);
 
 struct _BraseroLibisofsPrivate {
@@ -318,7 +325,7 @@ brasero_libisofs_create_image (BraseroLibisofs *self,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("Libisofs could not be initialized."));
+			     _("libisofs could not be initialized."));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -453,15 +460,6 @@ brasero_libisofs_import_last_session (BraseroLibisofs *self,
 	if (!priv->ctx)
 		return BRASERO_BURN_ERR;
 
-	result = iso_read_opts_new (&opts, 0);
-	if (result < 0) {
-		g_set_error (error,
-			     BRASERO_BURN_ERROR,
-			     BRASERO_BURN_ERROR_GENERAL,
-			     _("Read options could not be created"));
-		return BRASERO_BURN_ERR;
-	}
-
 	src = g_new0 (IsoDataSource, 1);
 	src->version = 0;
 	src->refcount = 1;
@@ -471,6 +469,15 @@ brasero_libisofs_import_last_session (BraseroLibisofs *self,
 	src->free_data = brasero_libisofs_import_free;
 	src->data = priv->ctx->drive;
 
+	result = iso_read_opts_new (&opts, 0);
+	if (result < 0) {
+		g_set_error (error,
+			     BRASERO_BURN_ERROR,
+			     BRASERO_BURN_ERROR_GENERAL,
+			     _("Read options could not be created"));
+		return BRASERO_BURN_ERR;
+	}
+
 	brasero_job_get_last_session_address (BRASERO_JOB (self), &session_block);
 	iso_read_opts_set_start_block (opts, session_block);
 
@@ -717,7 +724,7 @@ brasero_libisofs_create_volume_thread (gpointer data)
 							 result);
 					priv->error = g_error_new (BRASERO_BURN_ERROR,
 								   BRASERO_BURN_ERROR_GENERAL,
-								   _("Libisofs reported an error while creating directory \"%s\""),
+								   _("libisofs reported an error while creating directory \"%s\""),
 								   graft->path);
 					g_free (path_name);
 					goto end;
@@ -732,7 +739,7 @@ brasero_libisofs_create_volume_thread (gpointer data)
 							 result);
 					priv->error = g_error_new (BRASERO_BURN_ERROR,
 								   BRASERO_BURN_ERROR_GENERAL,
-								   _("Libisofs reported an error while adding contents to directory \"%s\" (%x)"),
+								   _("libisofs reported an error while adding contents to directory \"%s\" (%x)"),
 								   graft->path,
 								   result);
 					g_free (path_name);
@@ -755,7 +762,7 @@ brasero_libisofs_create_volume_thread (gpointer data)
 							 err);
 					priv->error = g_error_new (BRASERO_BURN_ERROR,
 								   BRASERO_BURN_ERROR_GENERAL,
-								   _("Libisofs reported an error while adding file at path \"%s\""),
+								   _("libisofs reported an error while adding file at path \"%s\""),
 								   graft->path);
 					g_free (path_name);
 					goto end;
@@ -771,7 +778,7 @@ brasero_libisofs_create_volume_thread (gpointer data)
 								 err);
 						priv->error = g_error_new (BRASERO_BURN_ERROR,
 									   BRASERO_BURN_ERROR_GENERAL,
-									   _("Libisofs reported an error while adding file at path \"%s\""),
+									   _("libisofs reported an error while adding file at path \"%s\""),
 									   graft->path);
 						g_free (path_name);
 						goto end;
@@ -784,7 +791,7 @@ brasero_libisofs_create_volume_thread (gpointer data)
 		else if (iso_tree_add_new_dir (ISO_DIR (parent), path_name, NULL) < 0) {
 			priv->error = g_error_new (BRASERO_BURN_ERROR,
 						   BRASERO_BURN_ERROR_GENERAL,
-						   _("Libisofs reported an error while creating directory \"%s\""),
+						   _("libisofs reported an error while creating directory \"%s\""),
 						   graft->path);
 			g_free (path_name);
 			goto end;
@@ -858,7 +865,7 @@ brasero_libisofs_create_volume (BraseroLibisofs *self, GError **error)
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("Libisofs could not be initialized."));
+			     _("libisofs could not be initialized."));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -1035,7 +1042,7 @@ brasero_libisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	brasero_plugin_define (plugin,
 			       "libisofs",
-			       _("Libisofs creates disc images from files"),
+			       _("libisofs creates disc images from files"),
 			       "Philippe Rouquier",
 			       0);
 
