@@ -44,12 +44,19 @@
 #include "brasero-units.h"
 #include "burn-job.h"
 #include "brasero-plugin-registration.h"
-#include "burn-uri.h"
 
 #include "brasero-track.h"
 #include "brasero-track-data.h"
 #include "brasero-track-image.h"
 
+
+#define BRASERO_TYPE_BURN_URI         (brasero_burn_uri_get_type ())
+#define BRASERO_BURN_URI(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), BRASERO_TYPE_BURN_URI, BraseroBurnURI))
+#define BRASERO_BURN_URI_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), BRASERO_TYPE_BURN_URI, BraseroBurnURIClass))
+#define BRASERO_IS_BURN_URI(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), BRASERO_TYPE_BURN_URI))
+#define BRASERO_IS_BURN_URI_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), BRASERO_TYPE_BURN_URI))
+#define BRASERO_BURN_URI_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), BRASERO_TYPE_BURN_URI, BraseroBurnURIClass))
+
 BRASERO_PLUGIN_BOILERPLATE (BraseroBurnURI, brasero_burn_uri, BRASERO_TYPE_JOB, BraseroJob);
 
 struct _BraseroBurnURIPrivate {
@@ -246,6 +253,9 @@ brasero_burn_uri_retrieve_path (BraseroBurnURI *self,
 
 	priv = BRASERO_BURN_URI_PRIVATE (self);
 
+	if (!uri)
+		return FALSE;
+
 	file = g_file_new_for_uri (uri);
 	info = g_file_query_info (file,
 				  G_FILE_ATTRIBUTE_STANDARD_NAME ","
@@ -336,12 +346,15 @@ brasero_burn_uri_thread (gpointer data)
 
 		path_toc = NULL;
 		uri = brasero_track_image_get_toc_source (BRASERO_TRACK_IMAGE (current), TRUE);
-		if (!brasero_burn_uri_retrieve_path (self, uri, &path_toc)) {
-			g_free (path_image);
+		if (uri) {
+			/* NOTE: if it's a .bin image there is not .toc file */
+			if (!brasero_burn_uri_retrieve_path (self, uri, &path_toc)) {
+				g_free (path_image);
+				g_free (uri);
+				goto end;
+			}
 			g_free (uri);
-			goto end;
 		}
-		g_free (uri);
 
 		brasero_track_get_size (current, &blocks, NULL);
 
@@ -731,7 +744,7 @@ brasero_burn_uri_export_caps (BraseroPlugin *plugin, gchar **error)
 				* which will be translated only when it needs
 				* displaying. */
 			       N_("CD/DVD Creator Folder"),
-			       _("Allows to burn files added to \"CD/DVD Creator Folder\" in Nautilus"),
+			       _("Allows files added to the \"CD/DVD Creator Folder\" in Nautilus to be burned"),
 			       "Philippe Rouquier",
 			       11);
 
