@@ -40,7 +40,13 @@
 #include <gtk/gtk.h>
 
 #include "brasero-misc.h"
-#include "burn-basics.h"
+#include "brasero-io.h"
+#include "brasero-notify.h"
+
+#include "brasero-tags.h"
+#include "brasero-track-stream-cfg.h"
+#include "brasero-session-cfg.h"
+
 #include "brasero-app.h"
 #include "brasero-disc.h"
 #include "brasero-audio-disc.h"
@@ -48,12 +54,8 @@
 #include "brasero-utils.h"
 #include "brasero-multi-song-props.h"
 #include "brasero-song-properties.h"
-#include "brasero-io.h"
 #include "brasero-split-dialog.h"
-#include "brasero-track-stream-cfg.h"
-#include "brasero-session-cfg.h"
 #include "brasero-video-tree-model.h"
-#include "brasero-tags.h"
 
 #include "eggtreemultidnd.h"
 
@@ -129,6 +131,7 @@ struct _BraseroAudioDiscPrivate {
 
 	GtkWidget *tree;
 
+	GtkWidget *message;
 	GtkUIManager *manager;
 	GtkActionGroup *disc_group;
 
@@ -148,7 +151,7 @@ static GtkActionEntry entries[] = {
 	{"ContextualMenu", NULL, N_("Menu")},
 	{"OpenSong", GTK_STOCK_OPEN, NULL, NULL, N_("Open the selected files"),
 	 G_CALLBACK (brasero_audio_disc_open_activated_cb)},
-	{"EditSong", GTK_STOCK_PROPERTIES, N_("_Edit Information..."), NULL, N_("Edit the track information (start, end, author, ...)"),
+	{"EditSong", GTK_STOCK_PROPERTIES, N_("_Edit Information…"), NULL, N_("Edit the track information (start, end, author, etc.)"),
 	 G_CALLBACK (brasero_audio_disc_edit_information_cb)},
 	{"DeleteAudio", GTK_STOCK_REMOVE, NULL, NULL, N_("Remove the selected files from the project"),
 	 G_CALLBACK (brasero_audio_disc_delete_activated_cb)},
@@ -156,7 +159,7 @@ static GtkActionEntry entries[] = {
 	 G_CALLBACK (brasero_audio_disc_paste_activated_cb)},
 	{"Pause", "insert-pause", N_("I_nsert a Pause"), NULL, N_("Add a 2 second pause after the track"),
 	 G_CALLBACK (brasero_audio_disc_add_pause_cb)},
-	{"Split", "transform-crop-and-resize", N_("_Split Track..."), NULL, N_("Split the selected track"),
+	{"Split", "transform-crop-and-resize", N_("_Split Track…"), NULL, N_("Split the selected track"),
 	 G_CALLBACK (brasero_audio_disc_split_cb)}
 };
 
@@ -218,6 +221,8 @@ enum {
 #define BRASERO_SECTORS_TO_TIME(sectors)	(gint64) (sectors * GST_SECOND / 75)
 #define COL_KEY "column_key"
 
+#define BRASERO_AUDIO_DISC_CONTEXT		1000
+
 static void brasero_audio_disc_iface_disc_init (BraseroDiscIface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (BraseroAudioDisc,
@@ -225,12 +230,23 @@ G_DEFINE_TYPE_WITH_CODE (BraseroAudioDisc,
 			 GTK_TYPE_VBOX,
 			 G_IMPLEMENT_INTERFACE (BRASERO_TYPE_DISC,
 					        brasero_audio_disc_iface_disc_init));
+static gboolean
+brasero_audio_disc_is_empty (BraseroDisc *disc)
+{
+	GtkTreeModel *model;
+
+	model = gtk_tree_view_get_model (GTK_TREE_VIEW (BRASERO_AUDIO_DISC (disc)->priv->tree));
+	return gtk_tree_model_iter_n_children (model, NULL) != 0;
+}
 
 static void
 brasero_audio_disc_iface_disc_init (BraseroDiscIface *iface)
 {
 	iface->add_uri = brasero_audio_disc_add_uri;
 	iface->delete_selected = brasero_audio_disc_delete_selected;
+
+	iface->is_empty = brasero_audio_disc_is_empty;
+
 	iface->set_session_contents = brasero_audio_disc_set_session_contents;
 	iface->get_selected_uri = brasero_audio_disc_get_selected_uri;
 	iface->get_boundaries = brasero_audio_disc_get_boundaries;
@@ -289,8 +305,15 @@ brasero_audio_disc_add_ui (BraseroDisc *disc,
 
 	audio_disc = BRASERO_AUDIO_DISC (disc);
 
+	if (audio_disc->priv->message) {
+		g_object_unref (audio_disc->priv->message);
+		audio_disc->priv->message = NULL;
+	}
+
+	audio_disc->priv->message = g_object_ref (message);
+
 	if (!audio_disc->priv->disc_group) {
-		audio_disc->priv->disc_group = gtk_action_group_new (BRASERO_DISC_ACTION);
+		audio_disc->priv->disc_group = gtk_action_group_new (BRASERO_DISC_ACTION "-audio");
 		gtk_action_group_set_translation_domain (audio_disc->priv->disc_group, GETTEXT_PACKAGE);
 		gtk_action_group_add_actions (audio_disc->priv->disc_group,
 					      entries,
@@ -419,7 +442,11 @@ brasero_audio_disc_init (BraseroAudioDisc *obj)
 
 	gtk_tree_view_column_pack_end (column, renderer, TRUE);
 	gtk_tree_view_column_add_attribute (column, renderer,
-					    "markup", BRASERO_VIDEO_TREE_MODEL_NAME);
+					    "text", BRASERO_VIDEO_TREE_MODEL_NAME);
+	gtk_tree_view_column_add_attribute (column, renderer,
+					    "style", BRASERO_VIDEO_TREE_MODEL_STYLE);
+	gtk_tree_view_column_add_attribute (column, renderer,
+					    "weight", BRASERO_VIDEO_TREE_MODEL_WEIGHT);
 	gtk_tree_view_column_add_attribute (column, renderer,
 					    "editable", BRASERO_VIDEO_TREE_MODEL_EDITABLE);
 	gtk_tree_view_column_set_title (column, _("Title"));
@@ -475,10 +502,6 @@ brasero_audio_disc_init (BraseroAudioDisc *obj)
 	gtk_container_add (GTK_CONTAINER (scroll), obj->priv->tree);
 
 	gtk_box_pack_start (GTK_BOX (obj), scroll, TRUE, TRUE, 0);
-	/*gtk_notebook_append_page (GTK_NOTEBOOK (obj->priv->notebook),
-				  scroll,
-				  NULL);
-	gtk_notebook_set_current_page (GTK_NOTEBOOK (obj->priv->notebook), 0);*/
 
 	/* dnd */
 	gtk_tree_view_enable_model_drag_dest (GTK_TREE_VIEW (obj->priv->tree),
@@ -505,6 +528,9 @@ brasero_audio_disc_reset_real (BraseroAudioDisc *disc)
 		gtk_tree_path_free (disc->priv->selected_path);
 		disc->priv->selected_path = NULL;
 	}
+
+	if (disc->priv->message)
+		brasero_notify_message_remove (BRASERO_NOTIFY (disc->priv->message), BRASERO_AUDIO_DISC_CONTEXT);
 }
 
 static void
@@ -520,6 +546,11 @@ brasero_audio_disc_finalize (GObject *object)
 	cobj->priv->add_dir = NULL;
 	cobj->priv->add_playlist = NULL;
 
+	if (cobj->priv->message) {
+		g_object_unref (cobj->priv->message);
+		cobj->priv->message = NULL;
+	}
+
 	if (cobj->priv->manager) {
 		g_object_unref (cobj->priv->manager);
 		cobj->priv->manager = NULL;
@@ -566,8 +597,8 @@ brasero_audio_disc_add_uri_real (BraseroAudioDisc *disc,
 				 GtkTreePath **path_return)
 {
 	BraseroTrackStreamCfg *track;
+	BraseroTrack *sibling = NULL;
 	BraseroSessionCfg *session;
-	BraseroTrack *sibling;
 	GtkTreeModel *store;
 
 	g_return_val_if_fail (uri != NULL, BRASERO_DISC_ERROR_UNKNOWN);
@@ -609,7 +640,7 @@ brasero_audio_disc_file_type_error_dialog (BraseroAudioDisc *disc,
 	gchar *name;
 
     	BRASERO_GET_BASENAME_FOR_DISPLAY (uri, name);
-	primary = g_strdup_printf (_("\"%s\" could not be handled by Gstreamer."), name);
+	primary = g_strdup_printf (_("\"%s\" could not be handled by GStreamer."), name);
 	brasero_app_alert (brasero_app_get_default (),
 			   primary,
 			   _("Make sure the appropriate codec is installed"),
@@ -628,7 +659,7 @@ brasero_audio_disc_video_file_dialog (BraseroAudioDisc *disc,
 	gchar *name;
 
     	BRASERO_GET_BASENAME_FOR_DISPLAY (uri, name);
-	string = g_strdup_printf (_("Do you want to add \"%s\" which is a video file?"), name);
+	string = g_strdup_printf (_("Do you want to add \"%s\", which is a video file?"), name);
 	dialog = brasero_app_dialog (brasero_app_get_default (),
 				     string,
 				     GTK_BUTTONS_NONE,
@@ -649,7 +680,7 @@ brasero_audio_disc_video_file_dialog (BraseroAudioDisc *disc,
 	answer = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 
-	return (answer == GTK_RESPONSE_OK);
+	return (answer != GTK_RESPONSE_OK);
 }
 
 static void
@@ -782,6 +813,70 @@ brasero_audio_disc_unreadable_dialog (BraseroAudioDisc *disc,
 	g_free (name);
 }
 
+static void
+brasero_audio_disc_wav_dts_response_cb (GtkButton *button,
+                                        GtkResponseType response,
+                                        BraseroAudioDisc *disc)
+{
+	BraseroSessionCfg *session;
+	GtkTreeModel *model;
+
+	model = gtk_tree_view_get_model (GTK_TREE_VIEW (disc->priv->tree));
+	session = brasero_video_tree_model_get_session (BRASERO_VIDEO_TREE_MODEL (model));
+
+	if (response == GTK_RESPONSE_OK)
+		brasero_burn_session_tag_add_int (BRASERO_BURN_SESSION (session),
+		                                  BRASERO_SESSION_STREAM_AUDIO_FORMAT,
+		                                  BRASERO_AUDIO_FORMAT_DTS);
+}
+
+static void
+brasero_audio_disc_wav_dts_file_dialog (BraseroAudioDisc *disc)
+{
+	GtkWidget *message;
+	BraseroSessionCfg *session;
+	GtkTreeModel *model;
+
+	if (brasero_notify_get_message_by_context_id (BRASERO_NOTIFY (disc->priv->message),
+	                                              BRASERO_AUDIO_DISC_CONTEXT))
+		return;
+
+	/* Add a tag (RAW by default) so that we won't try to display this message again */
+	model = gtk_tree_view_get_model (GTK_TREE_VIEW (disc->priv->tree));
+	session = brasero_video_tree_model_get_session (BRASERO_VIDEO_TREE_MODEL (model));
+	brasero_burn_session_tag_add_int (BRASERO_BURN_SESSION (session),
+	                                  BRASERO_SESSION_STREAM_AUDIO_FORMAT,
+	                                  BRASERO_AUDIO_FORMAT_RAW);
+
+	message = brasero_notify_message_add (BRASERO_NOTIFY (disc->priv->message),
+					      _("Do you want to create an audio CD with DTS tracks?"),
+					      _("Some of the selected songs are suitable for creating DTS tracks."
+					        "\nThis type of audio CD track provides a higher quality of sound but can only be played by specific digital players."
+					        "\nNote: if you agree, normalization will not be applied to these tracks."),
+					      0,
+					      BRASERO_AUDIO_DISC_CONTEXT);
+
+	brasero_disc_message_set_image (BRASERO_DISC_MESSAGE (message),
+					GTK_MESSAGE_INFO);
+
+	brasero_notify_button_add (BRASERO_NOTIFY (disc->priv->message),
+				   BRASERO_DISC_MESSAGE (message),
+				   _("Create _Regular Tracks"),
+				   _("Click here to burn all songs as regular tracks"),
+				   GTK_RESPONSE_NO);
+
+	brasero_notify_button_add (BRASERO_NOTIFY (disc->priv->message),
+				   BRASERO_DISC_MESSAGE (message),
+				   _("Create _DTS Tracks"),
+				   _("Click here to burn all suitable songs as DTS tracks"),
+				   GTK_RESPONSE_OK);
+
+	g_signal_connect (BRASERO_DISC_MESSAGE (message),
+			  "response",
+			  G_CALLBACK (brasero_audio_disc_wav_dts_response_cb),
+			  disc);
+}
+
 static void
 brasero_audio_disc_session_changed (BraseroSessionCfg *session,
 				    BraseroAudioDisc *self)
@@ -790,12 +885,14 @@ brasero_audio_disc_session_changed (BraseroSessionCfg *session,
 	GSList *tracks;
 	gboolean notready;
 	BraseroStatus *status;
+	gboolean should_use_dts;
 
 	if (!GTK_WIDGET (self)->window)
 		return;
 
 	/* make sure all tracks have video */
 	notready = FALSE;
+	should_use_dts = FALSE;
 	status = brasero_status_new ();
 	tracks = brasero_burn_session_get_tracks (BRASERO_BURN_SESSION (session));
 	for (; tracks; tracks = next) {
@@ -816,6 +913,12 @@ brasero_audio_disc_session_changed (BraseroSessionCfg *session,
 			gchar *uri;
 
 			uri = brasero_track_stream_get_source (track, TRUE);
+
+			/* Remove the track now otherwise on each session change we'll get the
+			 * same message over and over again. */
+			brasero_burn_session_remove_track (BRASERO_BURN_SESSION (session),
+							   BRASERO_TRACK (track));
+
 			error = brasero_status_get_error (status);
 			if (!error)
 				brasero_audio_disc_file_type_error_dialog (self, uri);
@@ -841,8 +944,6 @@ brasero_audio_disc_session_changed (BraseroSessionCfg *session,
 								      uri,
 								      error);
 
-			brasero_burn_session_remove_track (BRASERO_BURN_SESSION (session),
-							   BRASERO_TRACK (track));
 			g_error_free (error);
 			g_free (uri);
 			continue;
@@ -865,11 +966,14 @@ brasero_audio_disc_session_changed (BraseroSessionCfg *session,
 			brasero_burn_session_remove_track (BRASERO_BURN_SESSION (session),
 							   BRASERO_TRACK (track));
 			g_free (uri);
+			continue;
 		}
 
+		if ((format & BRASERO_AUDIO_FORMAT_DTS) != 0)
+			should_use_dts = TRUE;
+
 		if (BRASERO_STREAM_FORMAT_HAS_VIDEO (format)) {
 			gboolean res;
-
 			gchar *uri;
 
 			uri = brasero_track_stream_get_source (track, TRUE);
@@ -881,6 +985,10 @@ brasero_audio_disc_session_changed (BraseroSessionCfg *session,
 		}
 	}
 	brasero_status_free (status);
+
+	if (should_use_dts
+	&&  brasero_burn_session_tag_lookup (BRASERO_BURN_SESSION (session), BRASERO_SESSION_STREAM_AUDIO_FORMAT, NULL) != BRASERO_BURN_OK)
+		brasero_audio_disc_wav_dts_file_dialog (self);
 }
 
 static BraseroDiscResult
@@ -975,20 +1083,30 @@ brasero_audio_disc_set_session_contents (BraseroDisc *disc,
 					 BraseroBurnSession *session)
 {
 	BraseroAudioDisc *audio;
+	GtkTreeModel *current_model;
 	BraseroVideoTreeModel *model;
 
 	audio = BRASERO_AUDIO_DISC (disc);
 
+	if (audio->priv->add_dir)
+		brasero_io_cancel_by_base (audio->priv->add_dir);
+
+	if (audio->priv->add_playlist)
+		brasero_io_cancel_by_base (audio->priv->add_playlist);
+
+	/* disconnect some signals */
+	current_model = gtk_tree_view_get_model (GTK_TREE_VIEW (audio->priv->tree));
+	if (current_model) {
+		BraseroSessionCfg *current_session;
+
+		current_session = brasero_video_tree_model_get_session (BRASERO_VIDEO_TREE_MODEL (current_model));
+		if (current_session)
+			g_signal_handlers_disconnect_by_func (current_session,
+							      brasero_audio_disc_session_changed,
+							      disc);
+	}
+
 	if (!session) {
-		GtkTreeModel *model;
-		BraseroSessionCfg *session;
-
-		model = gtk_tree_view_get_model (GTK_TREE_VIEW (audio->priv->tree));
-		session = brasero_video_tree_model_get_session (BRASERO_VIDEO_TREE_MODEL (model));
-		g_signal_handlers_disconnect_by_func (session,
-						      brasero_audio_disc_session_changed,
-						      disc);
-
 		gtk_tree_view_set_model (GTK_TREE_VIEW (audio->priv->tree), NULL);
 		return BRASERO_DISC_OK;
 	}
