@@ -38,20 +38,8 @@
 
 #include <gtk/gtk.h>
 
-#include <libxml/xmlerror.h>
-#include <libxml/xmlwriter.h>
-#include <libxml/parser.h>
-#include <libxml/xmlstring.h>
-#include <libxml/uri.h>
-
-#include <gconf/gconf-client.h>
-
 #include <gst/gst.h>
 
-#ifdef BUILD_PLAYLIST
-#include <totem-pl-parser.h>
-#endif
-
 #include "brasero-units.h"
 
 #include "brasero-misc.h"
@@ -60,6 +48,8 @@
 #include "brasero-tags.h"
 #include "brasero-session.h"
 
+#include "brasero-setting.h"
+
 #ifdef BUILD_PREVIEW
 #include "brasero-player.h"
 #endif
@@ -192,7 +182,7 @@ struct BraseroProjectPrivate {
 static GtkActionEntry entries [] = {
 	{"Save", GTK_STOCK_SAVE, NULL, NULL,
 	 N_("Save current project"), G_CALLBACK (brasero_project_save_cb)},
-	{"SaveAs", GTK_STOCK_SAVE_AS, N_("Save _As..."), NULL,
+	{"SaveAs", GTK_STOCK_SAVE_AS, N_("Save _As…"), NULL,
 	 N_("Save current project to a different location"), G_CALLBACK (brasero_project_save_as_cb)},
 	{"Add", GTK_STOCK_ADD, N_("_Add Files"), NULL,
 	 N_("Add files to the project"), G_CALLBACK (brasero_project_add_uris_cb)},
@@ -201,7 +191,7 @@ static GtkActionEntry entries [] = {
 	/* Translators: "empty" is a verb here */
 	{"DeleteAll", GTK_STOCK_CLEAR, N_("E_mpty Project"), NULL,
 	 N_("Remove all files from the project"), G_CALLBACK (brasero_project_empty_cb)},
-	{"Burn", "media-optical-burn", N_("_Burn..."), NULL,
+	{"Burn", "media-optical-burn", N_("_Burn…"), NULL,
 	 N_("Burn the disc"), G_CALLBACK (brasero_project_burn_cb)},
 };
 
@@ -247,8 +237,6 @@ static GObjectClass *parent_class = NULL;
 
 #define BRASERO_PROJECT_SIZE_WIDGET_BORDER	1
 
-#define BRASERO_KEY_SHOW_PREVIEW		"/apps/brasero/display/viewer"
-
 #define BRASERO_PROJECT_VERSION "0.2"
 
 #define BRASERO_RESPONSE_ADD			1976
@@ -702,7 +690,7 @@ brasero_disc_get_use_info_notebook (BraseroProject *project)
 	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, "\n\t* ", -1, "TextBody", NULL);
 	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, _("drag files in this area from the selection pane or from the file manager"), -1, "TextBody", NULL);
 	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, "\n\t* ", -1, "TextBody", NULL);
-	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, _("double click on files in the selection pane"), -1, "TextBody", NULL);
+	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, _("double-click on files in the selection pane"), -1, "TextBody", NULL);
 	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, "\n\t* ", -1, "TextBody", NULL);
 	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, _("copy files (from file manager for example) and paste in this area"), -1, "TextBody", NULL);
 	gtk_text_buffer_insert (buffer, &iter, "\n\n\n", -1);
@@ -821,7 +809,7 @@ brasero_project_update_project_size (BraseroProject *project)
 	string = brasero_project_get_sectors_string (sectors, session_type);
 	brasero_track_type_free (session_type);
 
-	size_str = g_strdup_printf (_("Project estimated size: %s"), string);
+	size_str = g_strdup_printf (_("Estimated project size: %s"), string);
 	g_free (string);
 
 	gtk_statusbar_push (GTK_STATUSBAR (status), project->priv->status_ctx, size_str);
@@ -966,7 +954,7 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 
 			message = brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
 							      _("Would you like to burn the selection of files across several media?"),
-							      _("The size of the project is too large for the disc even with the overburn option."),
+							      _("The project is too large for the disc even with the overburn option."),
 							      -1,
 							      BRASERO_NOTIFY_CONTEXT_SIZE);
 			brasero_notify_button_add (BRASERO_NOTIFY (project->priv->message),
@@ -983,7 +971,7 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 		else
 			brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
 						    _("Please choose another CD or DVD or insert a new one."),
-						    _("The size of the project is too large for the disc even with the overburn option."),
+						    _("The project is too large for the disc even with the overburn option."),
 						    -1,
 						    BRASERO_NOTIFY_CONTEXT_SIZE);
 	}
@@ -993,16 +981,16 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 		project->priv->empty = FALSE;
 		project->priv->oversized = TRUE;
 		message = brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
-						      _("Would you like to burn beyond the disc reported capacity?"),
-						      _("The size of the project is too large for the disc and you must remove files from the project otherwise."
-							"\nYou may want to use this option if you're using 90 or 100 min CD-R(W) which cannot be properly recognised and therefore need overburn option."
-							"\nNOTE: This option might cause failure."),
+						      _("Would you like to burn beyond the disc's reported capacity?"),
+						      _("The project is too large for the disc and you must remove files from it."
+							"\nYou may want to use this option if you're using 90 or 100 min CD-R(W) which cannot be properly recognized and therefore needs the overburn option."
+							"\nNote: This option might cause failure."),
 						      -1,
 						      BRASERO_NOTIFY_CONTEXT_SIZE);
 		brasero_notify_button_add (BRASERO_NOTIFY (project->priv->message),
 					   BRASERO_DISC_MESSAGE (message),
 					   _("_Overburn"),
-					   _("Burn beyond the disc reported capacity"),
+					   _("Burn beyond the disc's reported capacity"),
 					   GTK_RESPONSE_OK);
 
 		g_signal_connect (message,
@@ -1013,8 +1001,8 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 	else if (valid == BRASERO_SESSION_NO_OUTPUT) {
 		project->priv->empty = FALSE;
 		brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
-					    _("Please insert a recordable CD or DVD."),
-					    _("There is no recordable disc inserted."),
+					    _("Please insert a writable CD or DVD."),
+					    NULL,
 					    -1,
 					    BRASERO_NOTIFY_CONTEXT_SIZE);
 	}
@@ -1038,7 +1026,7 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 		/* The user may have forgotten to insert a disc so remind him of that if
 		 * there aren't any other possibility in the selection */
 		brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
-					    _("Please insert a recordable CD or DVD if you don't want to write to an image file."),
+					    _("Please insert a writable CD or DVD if you don't want to write to an image file."),
 					    NULL,
 					    10000,
 					    BRASERO_NOTIFY_CONTEXT_SIZE);
@@ -1103,7 +1091,7 @@ brasero_project_init (BraseroProject *obj)
 	size_group = gtk_size_group_new (GTK_SIZE_GROUP_BOTH);
 
 	/* burn button set insensitive since there are no files in the selection */
-	obj->priv->burn = brasero_utils_make_button (_("_Burn..."),
+	obj->priv->burn = brasero_utils_make_button (_("_Burn…"),
 						     NULL,
 						     "media-optical-burn",
 						     GTK_ICON_SIZE_BUTTON);
@@ -1321,7 +1309,7 @@ brasero_project_check_status (BraseroProject *project)
                 return BRASERO_BURN_OK;
 
         dialog = brasero_status_dialog_new (BRASERO_BURN_SESSION (project->priv->session),
-                                            gtk_widget_get_toplevel (GTK_WIDGET (project)));
+                                                                  gtk_widget_get_toplevel (GTK_WIDGET (project)));
 
 	gtk_widget_show (dialog);
         response = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -2007,9 +1995,9 @@ brasero_project_add_uris_cb (GtkAction *action,
 		return;
 	}
 
-	/* set the Add button grey as we don't want
-	 * the user to be able to click again until it
-	 * the dialog has been closed */
+	/* Set the Add button grey as we don't want
+	 * the user to be able to click again until the
+	 * dialog has been closed */
 	gtk_action_set_sensitive (action, FALSE);
 
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (project));
@@ -2081,15 +2069,14 @@ brasero_project_add_uris_cb (GtkAction *action,
 
 #ifdef BUILD_PREVIEW
 
-	GConfClient *client;
 	GtkWidget *player;
-	gboolean res;
+	gpointer value;
 
-	client = gconf_client_get_default ();
-	res = gconf_client_get_bool (client, BRASERO_KEY_SHOW_PREVIEW, NULL);
-	g_object_unref (client);
+	brasero_setting_get_value (brasero_setting_get_default (),
+	                           BRASERO_SETTING_SHOW_PREVIEW,
+	                           &value);
 
-	if (!res)
+	if (!GPOINTER_TO_INT (value))
 		return;
 
 	/* if preview is activated add it */
@@ -2268,13 +2255,13 @@ brasero_project_set_uri (BraseroProject *project,
     	BRASERO_GET_BASENAME_FOR_DISPLAY (uri, name);
 	if (type == BRASERO_PROJECT_TYPE_DATA)
 		/* Translators: %s is the name of the project */
-		title = g_strdup_printf (_("Brasero - %s (Data Disc)"), name);
+		title = g_strdup_printf (_("Brasero — %s (Data Disc)"), name);
 	else if (type == BRASERO_PROJECT_TYPE_AUDIO)
 		/* Translators: %s is the name of the project */
-		title = g_strdup_printf (_("Brasero - %s (Audio Disc)"), name);
+		title = g_strdup_printf (_("Brasero — %s (Audio Disc)"), name);
 	else if (type == BRASERO_PROJECT_TYPE_VIDEO)
 		/* Translators: %s is the name of the project */
-		title = g_strdup_printf (_("Brasero - %s (Video Disc)"), name);
+		title = g_strdup_printf (_("Brasero — %s (Video Disc)"), name);
 	else
 		title = NULL;
  
@@ -2367,7 +2354,7 @@ brasero_project_not_saved_dialog (BraseroProject *project)
 	error = xmlGetLastError ();
 	brasero_app_alert (brasero_app_get_default (),
 			   _("Your project has not been saved."),
-			   error? error->message:_("An unknown error occured"),
+			   error? error->message:_("An unknown error occurred"),
 			   GTK_MESSAGE_ERROR);
 	xmlResetLastError ();
 }
@@ -2508,15 +2495,15 @@ brasero_project_save_project_ask_for_path (BraseroProject *project,
 		combo = gtk_combo_box_new_text ();
 		gtk_widget_show (combo);
 
-		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as Brasero audio project"));
+		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as a Brasero audio project"));
 		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as a plain text list"));
 
 #ifdef BUILD_PLAYLIST
 
 		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as a PLS playlist"));
 		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as an M3U playlist"));
-		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as a XSPF playlist"));
-		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as an IRIVER playlist"));
+		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as an XSPF playlist"));
+		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as an iriver playlist"));
 
 #endif
 
